@@ -32,7 +32,7 @@ end
 
 module type LIST = sig
   (* Added functions *)
-  val print : (Format.formatter -> 'a -> 'b) -> Format.formatter -> 'a list -> unit
+  val print : (Format.formatter -> 'a -> unit) -> Format.formatter -> 'a list -> unit
   val filter_opt : ('a -> 'b option) -> 'a list -> 'b list
   val union : 'a list -> 'a list -> 'a list
   val ordered_unique : 'a list -> 'a list
@@ -382,7 +382,9 @@ module type OPTIONS = sig
   val exclude_dirs : string list ref
   val nothing_should_be_rebuilt : bool ref
   val ocamlc : command_spec ref
+  val plugin_ocamlc : command_spec ref
   val ocamlopt : command_spec ref
+  val plugin_ocamlopt : command_spec ref
   val ocamldep : command_spec ref
   val ocamldoc : command_spec ref
   val ocamlyacc : command_spec ref
@@ -406,6 +408,7 @@ module type OPTIONS = sig
   val show_documentation : bool ref
   val recursive : bool ref
   val use_ocamlfind : bool ref
+  val plugin_use_ocamlfind : bool ref
 
   val targets : string list ref
   val ocaml_libs : string list ref
@@ -429,7 +432,7 @@ module type OPTIONS = sig
   val ext_dll : string ref
   val exe : string ref
 
-  val add : string * Arg.spec * string -> unit
+  val add : Arg.key * Arg.spec * Arg.doc -> unit
 end
 
 module type ARCH = sig
